==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1FlockerVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1FlockerVolumeSourceFluentImpl<A extends V1FlockerVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1FlockerVolumeSourceFluent<A>{

    private String datasetName;
    private String datasetUUID;

    public V1FlockerVolumeSourceFluentImpl(){
    }
    public V1FlockerVolumeSourceFluentImpl(V1FlockerVolumeSource instance){
            this.withDatasetName(instance.getDatasetName());

            this.withDatasetUUID(instance.getDatasetUUID());

    }

    public String getDatasetName(){
            return this.datasetName;
    }

    public A withDatasetName(String datasetName){
            this.datasetName=datasetName; return (A) this;
    }

    public Boolean hasDatasetName(){
            return this.datasetName != null;
    }

    public String getDatasetUUID(){
            return this.datasetUUID;
    }

    public A withDatasetUUID(String datasetUUID){
            this.datasetUUID=datasetUUID; return (A) this;
    }

    public Boolean hasDatasetUUID(){
            return this.datasetUUID != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1FlockerVolumeSourceFluentImpl that = (V1FlockerVolumeSourceFluentImpl) o;
            if (datasetName != null ? !datasetName.equals(that.datasetName) :that.datasetName != null) return false;
            if (datasetUUID != null ? !datasetUUID.equals(that.datasetUUID) :that.datasetUUID != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1FlockerVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1FlockerVolumeSourceFluentImpl<A extends V1FlockerVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1FlockerVolumeSourceFluent<A>{

    private String datasetName;
    private String datasetUUID;

    public V1FlockerVolumeSourceFluentImpl(){
    }
    public V1FlockerVolumeSourceFluentImpl(V1FlockerVolumeSource instance){
            this.withDatasetName(instance.getDatasetName());

            this.withDatasetUUID(instance.getDatasetUUID());

    }

    public String getDatasetName(){
            return this.datasetName;
    }

    public A withDatasetName(String datasetName){
            this.datasetName=datasetName; return (A) this;
    }

    public Boolean hasDatasetName(){
            return this.datasetName != null;
    }

    public A withNewDatasetName(String arg1){
            return (A)withDatasetName(new String(arg1));
    }

    public A withNewDatasetName(StringBuilder arg1){
            return (A)withDatasetName(new String(arg1));
    }

    public A withNewDatasetName(StringBuffer arg1){
            return (A)withDatasetName(new String(arg1));
    }

    public String getDatasetUUID(){
            return this.datasetUUID;
    }

    public A withDatasetUUID(String datasetUUID){
            this.datasetUUID=datasetUUID; return (A) this;
    }

    public Boolean hasDatasetUUID(){
            return this.datasetUUID != null;
    }

    public A withNewDatasetUUID(String arg1){
            return (A)withDatasetUUID(new String(arg1));
    }

    public A withNewDatasetUUID(StringBuilder arg1){
            return (A)withDatasetUUID(new String(arg1));
    }

    public A withNewDatasetUUID(StringBuffer arg1){
            return (A)withDatasetUUID(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1FlockerVolumeSourceFluentImpl that = (V1FlockerVolumeSourceFluentImpl) o;
            if (datasetName != null ? !datasetName.equals(that.datasetName) :that.datasetName != null) return false;
            if (datasetUUID != null ? !datasetUUID.equals(that.datasetUUID) :that.datasetUUID != null) return false;
            return true;
    }




}
